@@ -1,7 +1,7 @@
 /*
  * clipboard.h - the clipboard for patterns, notes etc.
  *
- * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -48,13 +48,24 @@
 
 class journallingObject;
 
-namespace clipboard
+class clipboard
 {
+public:
 	typedef QMap<QString, QDomElement> map;
-	extern map content;
 
-	void FASTCALL copy( journallingObject * _object );
-	const QDomElement * FASTCALL getContent( const QString & _node_name );
+	static void FASTCALL copy( journallingObject * _object );
+	static const QDomElement * FASTCALL getContent(
+						const QString & _node_name );
+
+	static const char * mimeType( void )
+	{
+		return( "application/x-lmms-clipboard" );
+	}
+
+
+private:
+	static map content;
+
 } ;
 
 #endif
