@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -27,6 +27,8 @@
 #define _LMMS_MATH_H
 
 
+
+
 // Equivalent to _x - floorf( _x )
 static inline float fraction( const float _x )
 {
@@ -35,4 +37,17 @@ static inline float fraction( const float _x )
 }
 
 
+
+
+#define FAST_RAND_MAX 32767
+static inline int fast_rand( void )
+{
+	static unsigned long next = 1;
+	next = next * 1103515245 + 12345;
+	return( (unsigned)( next / 65536 ) % 32768 );
+}
+
+
+
+
 #endif
